Class: Vatsense::Models::CurrencyCalculateVatPriceParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Vatsense::Models::CurrencyCalculateVatPriceParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/vatsense/models/currency_calculate_vat_price_params.rb
Overview
Defined Under Namespace
Modules: TaxType
Instance Attribute Summary collapse
-
#price ⇒ String
The price to calculate on.
-
#tax_type ⇒ Symbol, Vatsense::Models::CurrencyCalculateVatPriceParams::TaxType
Whether the provided price is inclusive or exclusive of VAT.
-
#vat_rate ⇒ Float
A percentage VAT rate to use for the calculation.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(price:, tax_type:, vat_rate:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CurrencyCalculateVatPriceParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(price:, tax_type:, vat_rate:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Vatsense::Models::CurrencyCalculateVatPriceParams for more details.
|
|
# File 'lib/vatsense/models/currency_calculate_vat_price_params.rb', line 29
|
Instance Attribute Details
#price ⇒ String
The price to calculate on. Must be a string with exactly 2 decimal places (e.g. “30.00”, “59.95”).
15 |
# File 'lib/vatsense/models/currency_calculate_vat_price_params.rb', line 15 required :price, String |
#tax_type ⇒ Symbol, Vatsense::Models::CurrencyCalculateVatPriceParams::TaxType
Whether the provided price is inclusive or exclusive of VAT.
21 |
# File 'lib/vatsense/models/currency_calculate_vat_price_params.rb', line 21 required :tax_type, enum: -> { Vatsense::CurrencyCalculateVatPriceParams::TaxType } |
#vat_rate ⇒ Float
A percentage VAT rate to use for the calculation.
27 |
# File 'lib/vatsense/models/currency_calculate_vat_price_params.rb', line 27 required :vat_rate, Float |