Class: Vatsense::Models::RateDetailsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/vatsense/models/rate_details_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country_code: nil, eu: nil, ip_address: nil, period: nil, province_code: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Vatsense::Models::RateDetailsParams for more details.

Parameters:

  • country_code (String) (defaults to: nil)

    A 2-character ISO 3166-1 alpha-2 country code (e.g. “GB”, “FR”).

  • eu (Boolean) (defaults to: nil)

    Filter results by EU membership. Use 1 for EU countries only, 0 for non-EU only.

  • ip_address (String) (defaults to: nil)

    An IPv4 or IPv6 address. If provided, the country will be determined from the IP

  • period (Time) (defaults to: nil)

    A historical date to retrieve rates for (format “YYYY-MM-DD HH:MM:SS”). Must be

  • province_code (String) (defaults to: nil)

    A 2-character province code (e.g. “NU”, “NT”). If providing a province

  • type (String) (defaults to: nil)

    The product type to find the applicable rate for. See the /rates/types

  • request_options (Vatsense::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/vatsense/models/rate_details_params.rb', line 50

Instance Attribute Details

#country_codeString?

A 2-character ISO 3166-1 alpha-2 country code (e.g. “GB”, “FR”).

Returns:

  • (String, nil)


14
# File 'lib/vatsense/models/rate_details_params.rb', line 14

optional :country_code, String

#euBoolean?

Filter results by EU membership. Use 1 for EU countries only, 0 for non-EU only.

Returns:

  • (Boolean, nil)


20
# File 'lib/vatsense/models/rate_details_params.rb', line 20

optional :eu, Vatsense::Internal::Type::Boolean

#ip_addressString?

An IPv4 or IPv6 address. If provided, the country will be determined from the IP address.

Returns:

  • (String, nil)


27
# File 'lib/vatsense/models/rate_details_params.rb', line 27

optional :ip_address, String

#periodTime?

A historical date to retrieve rates for (format “YYYY-MM-DD HH:MM:SS”). Must be a past date.

Returns:

  • (Time, nil)


34
# File 'lib/vatsense/models/rate_details_params.rb', line 34

optional :period, Time

#province_codeString?

A 2-character province code (e.g. “NU”, “NT”). If providing a province code, you must also provide the relevant country_code.

Returns:

  • (String, nil)


41
# File 'lib/vatsense/models/rate_details_params.rb', line 41

optional :province_code, String

#typeString?

The product type to find the applicable rate for. See the /rates/types endpoint for a full list of valid values.

Returns:

  • (String, nil)


48
# File 'lib/vatsense/models/rate_details_params.rb', line 48

optional :type, String