Class: Vatsense::Models::CreateInvoice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Vatsense::Models::CreateInvoice
- Defined in:
- lib/vatsense/models/create_invoice.rb
Direct Known Subclasses
Defined Under Namespace
Instance Attribute Summary collapse
- #business ⇒ Vatsense::Models::InvoiceBusinessInput
- #conversion ⇒ Vatsense::Models::InvoiceConversionInput?
-
#currency_code ⇒ String
The 3-character currency code the invoice is billed in.
- #customer ⇒ Vatsense::Models::InvoiceCustomerInput?
-
#date ⇒ String
The date the invoice was issued (YYYY-MM-DD or YYYY-MM-DD HH:MM:SS).
-
#has_vat ⇒ Boolean?
Whether the invoice is subject to VAT.
-
#invoice_number ⇒ String?
A unique invoice number.
-
#is_copy ⇒ Boolean?
Whether the invoice is a copy of a primary invoice.
-
#is_reverse_charge ⇒ Boolean?
Whether the invoice is zero-rated due to reverse charge.
- #items ⇒ Array<Vatsense::Models::Invoice::InvoiceItemInput>
-
#notes ⇒ String?
Any additional notes for the invoice.
-
#pad_invoice_number ⇒ Integer?
Pad the auto-generated invoice number with leading zeros to this length.
-
#serial ⇒ String?
A serial prepended to the auto-generated invoice number.
-
#tax_point ⇒ String
The tax point or “time of supply” (YYYY-MM-DD or YYYY-MM-DD HH:MM:SS).
-
#tax_type ⇒ Symbol, ...
Whether item prices include or exclude VAT.
-
#type ⇒ Symbol, ...
The type of invoice.
-
#zero_rated ⇒ Boolean?
Whether the invoice has been zero-rated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(business:, currency_code:, date:, items:, tax_point:, conversion: nil, customer: nil, has_vat: nil, invoice_number: nil, is_copy: nil, is_reverse_charge: nil, notes: nil, pad_invoice_number: nil, serial: nil, tax_type: nil, type: nil, zero_rated: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CreateInvoice for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(business:, currency_code:, date:, items:, tax_point:, conversion: nil, customer: nil, has_vat: nil, invoice_number: nil, is_copy: nil, is_reverse_charge: nil, notes: nil, pad_invoice_number: nil, serial: nil, tax_type: nil, type: nil, zero_rated: nil) ⇒ Object
Some parameter documentations has been truncated, see Vatsense::Models::CreateInvoice for more details.
|
|
# File 'lib/vatsense/models/create_invoice.rb', line 106
|
Instance Attribute Details
#business ⇒ Vatsense::Models::InvoiceBusinessInput
9 |
# File 'lib/vatsense/models/create_invoice.rb', line 9 required :business, -> { Vatsense::InvoiceBusinessInput } |
#conversion ⇒ Vatsense::Models::InvoiceConversionInput?
37 |
# File 'lib/vatsense/models/create_invoice.rb', line 37 optional :conversion, -> { Vatsense::InvoiceConversionInput } |
#currency_code ⇒ String
The 3-character currency code the invoice is billed in.
15 |
# File 'lib/vatsense/models/create_invoice.rb', line 15 required :currency_code, String |
#customer ⇒ Vatsense::Models::InvoiceCustomerInput?
42 |
# File 'lib/vatsense/models/create_invoice.rb', line 42 optional :customer, -> { Vatsense::InvoiceCustomerInput } |
#date ⇒ String
The date the invoice was issued (YYYY-MM-DD or YYYY-MM-DD HH:MM:SS).
21 |
# File 'lib/vatsense/models/create_invoice.rb', line 21 required :date, String |
#has_vat ⇒ Boolean?
Whether the invoice is subject to VAT.
48 |
# File 'lib/vatsense/models/create_invoice.rb', line 48 optional :has_vat, Vatsense::Internal::Type::Boolean |
#invoice_number ⇒ String?
A unique invoice number. If not provided, defaults to an auto-incremented number.
55 |
# File 'lib/vatsense/models/create_invoice.rb', line 55 optional :invoice_number, String |
#is_copy ⇒ Boolean?
Whether the invoice is a copy of a primary invoice.
61 |
# File 'lib/vatsense/models/create_invoice.rb', line 61 optional :is_copy, Vatsense::Internal::Type::Boolean |
#is_reverse_charge ⇒ Boolean?
Whether the invoice is zero-rated due to reverse charge.
67 |
# File 'lib/vatsense/models/create_invoice.rb', line 67 optional :is_reverse_charge, Vatsense::Internal::Type::Boolean |
#items ⇒ Array<Vatsense::Models::Invoice::InvoiceItemInput>
26 |
# File 'lib/vatsense/models/create_invoice.rb', line 26 required :items, -> { Vatsense::Internal::Type::ArrayOf[Vatsense::Invoice::InvoiceItemInput] } |
#notes ⇒ String?
Any additional notes for the invoice.
73 |
# File 'lib/vatsense/models/create_invoice.rb', line 73 optional :notes, String |
#pad_invoice_number ⇒ Integer?
Pad the auto-generated invoice number with leading zeros to this length.
79 |
# File 'lib/vatsense/models/create_invoice.rb', line 79 optional :pad_invoice_number, Integer |
#serial ⇒ String?
A serial prepended to the auto-generated invoice number. Each unique serial has its own auto-increment range.
86 |
# File 'lib/vatsense/models/create_invoice.rb', line 86 optional :serial, String |
#tax_point ⇒ String
The tax point or “time of supply” (YYYY-MM-DD or YYYY-MM-DD HH:MM:SS).
32 |
# File 'lib/vatsense/models/create_invoice.rb', line 32 required :tax_point, String |
#tax_type ⇒ Symbol, ...
Whether item prices include or exclude VAT.
92 |
# File 'lib/vatsense/models/create_invoice.rb', line 92 optional :tax_type, enum: -> { Vatsense::CreateInvoice::TaxType } |
#type ⇒ Symbol, ...
The type of invoice.
98 |
# File 'lib/vatsense/models/create_invoice.rb', line 98 optional :type, enum: -> { Vatsense::CreateInvoice::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/vatsense/models/create_invoice.rb', line 153
|